Error handling
--------------

.. automodule:: pyroSAR.gamma.error
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        gammaErrorHandler
        GammaUnknownError